@@ -22,17 +22,24 @@
 #include <inttypes.h>
 #include <sqlite3.h>
 
+struct dt_develop_t;
+struct dt_iop_module_t;
+
 /** helper function to free a GList of dt_history_item_t */
 void dt_history_item_free(gpointer data);
 
-/** adds to memory.style_items instances of operations that shoudn't be modified by the copy/paste or style */
-void dt_history_rebuild_multi_priority_merge(const int dest_imgid);
+/** adds to dev_dest module mod_src */
+int dt_history_merge_module_into_history(struct dt_develop_t *dev_dest, struct dt_develop_t *dev_src, struct dt_iop_module_t *mod_src, GList **_modules_used, const int append);
 
 /** copy history from imgid and pasts on dest_imgid, merge or overwrite... */
 int dt_history_copy_and_paste_on_image(int32_t imgid, int32_t dest_imgid, gboolean merge, GList *ops);
 
+/** delete all history for the given image */
 void dt_history_delete_on_image(int32_t imgid);
 
+/** as above but control whether to record undo/redo */
+void dt_history_delete_on_image_ext(int32_t imgid, gboolean undo);
+
 /** copy history from imgid and pasts on selected images, merge or overwrite... */
 int dt_history_copy_and_paste_on_selection(int32_t imgid, gboolean merge, GList *ops);
 
@@ -45,6 +52,14 @@ int dt_history_load_and_apply(int imgid, gchar *filename, int history_only);
 /** delete historystack of selected images */
 void dt_history_delete_on_selection();
 
+/** compress history stack */
+int dt_history_compress_on_selection();
+void dt_history_compress_on_image(int32_t imgid);
+/* set or clear a tag representing an error state while compressing history */
+void dt_history_set_compress_problem(int32_t imgid, gboolean set);
+/* duplicate an history list */
+GList *dt_history_duplicate(GList *hist);
+
 typedef struct dt_history_item_t
 {
   guint num;
@@ -58,6 +73,9 @@ GList *dt_history_get_items(int32_t imgid, gboolean enabled);
 /** get list of history items for image as a nice string */
 char *dt_history_get_items_as_string(int32_t imgid);
 
+/* check if a module exists in the history of corresponding image */
+gboolean dt_history_check_module_exists(int32_t imgid, const char *operation);
+
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
 // kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
