@@ -148,42 +148,6 @@ static void _pop_undo(gpointer user_data, dt_undo_type_t type, dt_undo_data_t da
   }
 }
 
-static dt_undo_tags_t *_get_tags(const int imgid, const guint tagid, gboolean add)
-{
-  dt_undo_tags_t *undotags = (dt_undo_tags_t *)malloc(sizeof(dt_undo_tags_t));
-  undotags->imgid  = imgid;
-  undotags->before = dt_tag_get_tags(imgid);
-  undotags->after = g_list_copy(undotags->before);
-  GList *tag = g_list_find(undotags->after, GINT_TO_POINTER(tagid));
-  if(tag)
-  {
-    if(!add) undotags->after = g_list_remove(undotags->after, GINT_TO_POINTER(tagid));
-  }
-  else
-  {
-    if(add) undotags->after = g_list_prepend(undotags->after, GINT_TO_POINTER(tagid));
-  }
-  return undotags;
-}
-
-GList *_get_tags_selection(const guint tagid, const gboolean add)
-{
-  GList *result = NULL;
-
-  sqlite3_stmt *stmt;
-  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "SELECT imgid FROM main.selected_images", -1, &stmt, NULL);
-
-  while(sqlite3_step(stmt) == SQLITE_ROW)
-  {
-    const int imgid = sqlite3_column_int(stmt, 0);
-    result = g_list_append(result, _get_tags(imgid, tagid, add));
-  }
-
-  sqlite3_finalize(stmt);
-
-  return result;
-}
-
 static void _undo_tags_free(gpointer data)
 {
   dt_undo_tags_t *undotags = (dt_undo_tags_t *)data;
@@ -390,9 +354,9 @@ gboolean dt_tag_exists(const char *name, guint *tagid)
   return FALSE;
 }
 
-static void _tag_add_tags_to_list(GList **list, GList *tags)
+static void _tag_add_tags_to_list(GList **list, const GList *tags)
 {
-  GList *t = tags;
+  const GList *t = tags;
   while(t)
   {
     if(!g_list_find(*list, t->data))
@@ -403,15 +367,12 @@ static void _tag_add_tags_to_list(GList **list, GList *tags)
   }
 }
 
-static void _tag_remove_tags_from_list(GList **list, GList *tags)
+static void _tag_remove_tags_from_list(GList **list, const GList *tags)
 {
-  GList *t = tags;
+  const GList *t = tags;
   while(t)
   {
-    if(g_list_find(*list, t->data))
-    {
-      *list = g_list_remove(*list, t->data);
-    }
+    *list = g_list_remove(*list, t->data);
     t = g_list_next(t);
   }
 }
@@ -420,18 +381,19 @@ typedef enum dt_tag_actions_t
 {
   DT_TA_ATTACH = 0,
   DT_TA_DETACH,
-  DT_TA_SET
+  DT_TA_SET,
+  DT_TA_CLEAR
 } dt_tag_actions_t;
 
-static void _tag_execute(GList *tags, GList *imgs, GList **undo, const gboolean undo_on, const gint action)
+static void _tag_execute(const GList *tags, const GList *imgs, GList **undo, const gboolean undo_on, const gint action)
 {
-  GList *images = imgs;
+  const GList *images = imgs;
   while(images)
   {
     const int image_id = GPOINTER_TO_INT(images->data);
     dt_undo_tags_t *undotags = (dt_undo_tags_t *)malloc(sizeof(dt_undo_tags_t));
     undotags->imgid = image_id;
-    undotags->before = dt_tag_get_tags(image_id);
+    undotags->before = dt_tag_get_tags(image_id, FALSE);
     switch(action)
     {
       case DT_TA_ATTACH:
@@ -443,7 +405,10 @@ static void _tag_execute(GList *tags, GList *imgs, GList **undo, const gboolean
         _tag_remove_tags_from_list(&undotags->after, tags);
         break;
       case DT_TA_SET:
-        undotags->after = g_list_copy(tags);
+        undotags->after = g_list_copy((GList *)tags);
+        break;
+      case DT_TA_CLEAR:
+        undotags->after = dt_tag_get_tags(image_id, TRUE);
         break;
       default:
         undotags->after = g_list_copy(undotags->before);
@@ -580,13 +545,9 @@ void dt_tag_attach_string_list(const gchar *tags, gint imgid, const gboolean und
   g_strfreev(tokens);
 }
 
-void dt_tag_detach(const guint tagid, const gint imgid, const gboolean undo_on, const gboolean group_on)
+void dt_tag_detach_images(const guint tagid, const GList *img, const gboolean undo_on, const gboolean group_on)
 {
-  GList *imgs = NULL;
-  if(imgid == -1)
-    imgs = dt_collection_get_selected(darktable.collection, -1);
-  else
-    imgs = g_list_append(imgs, GINT_TO_POINTER(imgid));
+  GList *imgs = g_list_copy((GList *)img);
   if(imgs)
   {
     GList *tags = NULL;
@@ -607,6 +568,44 @@ void dt_tag_detach(const guint tagid, const gint imgid, const gboolean undo_on,
   }
 }
 
+void dt_tag_detach(const guint tagid, const gint imgid, const gboolean undo_on, const gboolean group_on)
+{
+  GList *imgs = NULL;
+  if(imgid == -1)
+    imgs = dt_collection_get_selected(darktable.collection, -1);
+  else
+    imgs = g_list_append(imgs, GINT_TO_POINTER(imgid));
+
+  dt_tag_detach_images(tagid, imgs, undo_on, group_on);
+  g_list_free(imgs);
+}
+
+
+void dt_tag_clear(const gint imgid, const gboolean undo_on, const gboolean group_on)
+{
+  GList *imgs = NULL;
+  if(imgid == -1)
+    imgs = dt_collection_get_selected(darktable.collection, -1);
+  else
+    imgs = g_list_append(imgs, GINT_TO_POINTER(imgid));
+
+  if(imgs)
+  {
+    GList *undo = NULL;
+    if(group_on) dt_grouping_add_grouped_images(&imgs);
+    if(undo_on) dt_undo_start_group(darktable.undo, DT_UNDO_TAGS);
+
+    _tag_execute(NULL, imgs, &undo, undo_on, DT_TA_CLEAR);
+
+    g_list_free(imgs);
+    if(undo_on)
+    {
+      dt_undo_record(darktable.undo, NULL, DT_UNDO_TAGS, undo, _pop_undo, _tags_undo_data_free);
+      dt_undo_end_group(darktable.undo);
+    }
+  }
+}
+
 void dt_tag_detach_from_gui(const guint tagid, const gint imgid, const gboolean undo_on, const gboolean group_on)
 {
   dt_tag_detach(tagid, imgid, undo_on, group_on);
@@ -670,8 +669,8 @@ uint32_t dt_tag_get_attached(gint imgid, GList **result, gboolean ignore_dt_tags
       DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
               "SELECT DISTINCT I.tagid, T.name, T.flags, T.synonyms, COUNT(DISTINCT S.imgid) AS inb "
               "FROM main.selected_images AS S "
-              "LEFT JOIN main.tagged_images AS I ON I.imgid = S.imgid "
-              "LEFT JOIN data.tags AS T ON T.id = I.tagid "
+              "JOIN main.tagged_images AS I ON I.imgid = S.imgid "
+              "JOIN data.tags AS T ON T.id = I.tagid "
               "WHERE T.id NOT IN memory.darktable_tags "
               "GROUP BY I.tagid "
               "ORDER by T.name",
@@ -680,8 +679,8 @@ uint32_t dt_tag_get_attached(gint imgid, GList **result, gboolean ignore_dt_tags
       DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
               "SELECT DISTINCT I.tagid, T.name, T.flags, T.synonyms, COUNT(DISTINCT S.imgid) AS inb "
               "FROM main.selected_images AS S "
-              "LEFT JOIN main.tagged_images AS I ON I.imgid = S.imgid "
-              "LEFT JOIN data.tags AS T ON T.id = I.tagid "
+              "JOIN main.tagged_images AS I ON I.imgid = S.imgid "
+              "JOIN data.tags AS T ON T.id = I.tagid "
               "GROUP BY I.tagid "
               "ORDER by T.name",
               -1, &stmt, NULL);
@@ -886,7 +885,7 @@ GList *dt_tag_get_hierarchical(gint imgid)
   return tags;
 }
 
-GList *dt_tag_get_tags(gint imgid)
+GList *dt_tag_get_tags(const gint imgid, const gboolean dt_tags)
 {
   GList *tags = NULL;
   if(imgid < 0) return tags;
@@ -897,8 +896,8 @@ GList *dt_tag_get_tags(gint imgid)
   snprintf(query, sizeof(query), "SELECT DISTINCT T.id "
                                  "FROM main.tagged_images AS I "
                                  "JOIN data.tags T on T.id = I.tagid "
-                                 "WHERE I.imgid = %d "
-                                 "AND T.id NOT IN memory.darktable_tags", imgid);
+                                 "WHERE I.imgid = %d %s",
+           imgid, dt_tags ? "AND T.id IN memory.darktable_tags" : "");
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
 
   while(sqlite3_step(stmt) == SQLITE_ROW)
