@@ -862,8 +862,8 @@ dt_iop_module_t *dt_iop_gui_duplicate(dt_iop_module_t *base, gboolean copy_param
 
   if(dt_conf_get_bool("darkroom/ui/single_module"))
   {
-    dt_iop_gui_set_expanded(base, FALSE, FALSE);
-    dt_iop_gui_set_expanded(module, TRUE, FALSE);
+    dt_iop_gui_set_expanded(base, FALSE, TRUE);
+    dt_iop_gui_set_expanded(module, TRUE, TRUE);
   }
 
   /* setup key accelerators */
@@ -944,6 +944,7 @@ static gboolean _rename_module_key_press(GtkWidget *entry, GdkEventKey *event, d
   if(ended)
   {
     gtk_widget_destroy(d->floating_window);
+    gtk_window_present(GTK_WINDOW(dt_ui_main_window(darktable.gui->ui)));
     free(d);
     return TRUE;
   }
@@ -1899,6 +1900,11 @@ static gboolean _iop_plugin_header_button_press(GtkWidget *w, GdkEventButton *e,
       g_object_set_data(G_OBJECT(container), "source_data", user_data);
       return FALSE;
     }
+    else if(e->state & GDK_CONTROL_MASK)
+    {
+      _iop_gui_rename_module(module);
+      return FALSE;
+    }
     else
     {
     // make gtk scroll to the module once it updated its allocation size
