@@ -181,6 +181,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Fujifilm FinePix S9600fd", { 12343,-4515,-1285,-7165,14899,2435,-1895,2496,8800 } }, // Copied from above
     { "Fujifilm GFX 50R", { 11756,-4754,-874,-3056,11045,2305,-381,1457,6006 } },
     { "Fujifilm GFX 50S", { 11756,-4754,-874,-3056,11045,2305,-381,1457,6006 } },
+    { "Fujifilm GFX 100", { 16212,-8423,-1583,-4336,12583,1937,-195,726,6199 } },
     { "Fujifilm IS-1", { 21461,-10807,-1441,-2332,10599,1999,289,875,7703 } },
     { "Fujifilm FinePix IS Pro", { 12300,-5110,-1304,-9117,17143,1998,-1947,2448,8100 } },
     { "Fujifilm FinePix HS10 HS11", { 12440,-3954,-1183,-1123,9674,1708,-83,1614,4086 } },
@@ -190,6 +191,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Fujifilm X100F", { 11434,-4948,-1210,-3746,12042,1903,-666,1479,5235 } },
     { "Fujifilm X100T", { 10592,-4262,-1008,-3514,11355,2465,-870,2025,6386 } },
     { "Fujifilm X100S", { 10592,-4262,-1008,-3514,11355,2465,-870,2025,6386 } },
+    { "Fujifilm X100V", { 13426,-6334,-1177,-4244,12136,2371,-580,1303,5980 } },
     { "Fujifilm FinePix X100", { 12161,-4457,-1069,-5034,12874,2400,-795,1724,6904 } },
     { "Fujifilm FinePix X10", { 13509,-6199,-1254,-4430,12733,1865,-331,1441,5022 } },
     { "Fujifilm X20", { 11768,-4971,-1133,-4904,12927,2183,-480,1723,4605 } },
@@ -360,6 +362,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Nikon COOLPIX B700", { 14387,-6014,-1299,-1357,9975,1616,467,1047,4744 } },
     { "Nikon Coolpix P330", { 10321,-3920,-931,-2750,11146,1824,-442,1545,5539 } },
     { "Nikon Coolpix P340", { 10321,-3920,-931,-2750,11146,1824,-442,1545,5539 } },
+    { "Nikon COOLPIX P950", { 13307,-5641,-1290,-2048,10581,1689,-64,1222,5176 } },
     { "Nikon COOLPIX P1000", { 14294,-6116,-1333,-1628,10219,1637,-14,1158,5022 } },
     { "Nikon Coolpix P6000", { 9698,-3367,-914,-4706,12584,2368,-837,968,5801 } },
     { "Nikon Coolpix P7000", { 11432,-3679,-1111,-3169,11239,2202,-791,1380,4455 } },
@@ -422,6 +425,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Olympus E-M1", { 7687,-1984,-606,-4327,11928,2721,-1381,2339,6452 } },
     { "Olympus E-M1X", { 11896,-5110,-1076,-3181,11378,2048,-519,1224,5166 } },
     { "Olympus E-M1MarkII", { 9383,-3170,-763,-2457,10702,2020,-384,1236,5552 } },
+    { "Olympus E-M1MarkIII", { 11896,-5110,-1076,-3181,11378,2048,-519,1224,5166 } },
     { "Olympus E-M5 Mark II", { 9422,-3258,-711,-2655,10898,2015,-512,1354,5512 } },
     { "Olympus E-M5 Mark III", { 11896,-5110,-1076,-3181,11378,2048,-519,1224,5166 } },
     { "Olympus E-M5", { 8380,-2630,-639,-2887,10725,2496,-627,1427,5438 } },
