@@ -560,7 +560,7 @@ int mouse_moved(struct dt_iop_module_t *self, double x, double y, double pressur
     else if(grab == 2) // change the width
     {
       float max = 0.5 * ((p->whratio <= 1.0) ? bigger_side * p->whratio : bigger_side);
-      float new_vignette_w = MIN(bigger_side * 0.5, MAX(0.1, pzx * wd - vignette_x));
+      float new_vignette_w = MIN(bigger_side, MAX(0.1, pzx * wd - vignette_x));
       float ratio = new_vignette_w / vignette_h;
       float new_scale = 100.0 * new_vignette_w / max;
       // FIXME: When going over the 1.0 boundary from wide to narrow (>1.0 -> <=1.0) the height slightly
@@ -590,7 +590,7 @@ int mouse_moved(struct dt_iop_module_t *self, double x, double y, double pressur
     }
     else if(grab == 4) // change the height
     {
-      float new_vignette_h = MIN(bigger_side * 0.5, MAX(0.1, vignette_y - pzy * ht));
+      float new_vignette_h = MIN(bigger_side, MAX(0.1, vignette_y - pzy * ht));
       float ratio = new_vignette_h / vignette_w;
       float max = 0.5 * ((ratio <= 1.0) ? bigger_side * (2.0 - p->whratio) : bigger_side);
       // FIXME: When going over the 1.0 boundary from narrow to wide (>1.0 -> <=1.0) the width slightly
@@ -624,7 +624,7 @@ int mouse_moved(struct dt_iop_module_t *self, double x, double y, double pressur
     {
       float new_vignette_fx = pzx * wd - vignette_x;
       float max = 0.5 * ((p->whratio <= 1.0) ? bigger_side * p->whratio : bigger_side);
-      float delta_x = MIN(max, MAX(0.0, new_vignette_fx - vignette_w));
+      float delta_x = MIN(2.0f * max, MAX(0.0, new_vignette_fx - vignette_w));
       float new_falloff = 100.0 * delta_x / max;
       dt_bauhaus_slider_set(g->falloff_scale, new_falloff);
     }
@@ -632,7 +632,7 @@ int mouse_moved(struct dt_iop_module_t *self, double x, double y, double pressur
     {
       float new_vignette_fy = vignette_y - pzy * ht;
       float max = 0.5 * ((p->whratio > 1.0) ? bigger_side * (2.0 - p->whratio) : bigger_side);
-      float delta_y = MIN(max, MAX(0.0, new_vignette_fy - vignette_h));
+      float delta_y = MIN(2.0f * max, MAX(0.0, new_vignette_fy - vignette_h));
       float new_falloff = 100.0 * delta_y / max;
       dt_bauhaus_slider_set(g->falloff_scale, new_falloff);
     }
@@ -1138,8 +1138,8 @@ void gui_init(struct dt_iop_module_t *self)
 
   label1 = dtgtk_reset_label_new(_("automatic ratio"), self, &p->autoratio, sizeof p->autoratio);
 
-  g->scale = dt_bauhaus_slider_new_with_range(self, 0.0, 100.0, 0.5, p->scale, 2);
-  g->falloff_scale = dt_bauhaus_slider_new_with_range(self, 0.0, 100.0, 1.0, p->falloff_scale, 2);
+  g->scale = dt_bauhaus_slider_new_with_range(self, 0.0, 200.0, 0.5, p->scale, 2);
+  g->falloff_scale = dt_bauhaus_slider_new_with_range(self, 0.0, 200.0, 1.0, p->falloff_scale, 2);
   g->brightness = dt_bauhaus_slider_new_with_range(self, -1.0, 1.0, 0.01, p->brightness, 3);
   g->saturation = dt_bauhaus_slider_new_with_range(self, -1.0, 1.0, 0.01, p->saturation, 3);
   g->center_x = dt_bauhaus_slider_new_with_range(self, -1.0, 1.0, 0.01, p->center.x, 3);
