@@ -90,7 +90,7 @@ static gboolean _lib_duplicate_caption_out_callback(GtkWidget *widget, GdkEvent
   int imgid = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget),"imgid"));
 
   // we write the content of the textbox to the caption field
-  dt_metadata_set(imgid, "Xmp.dc.title", gtk_entry_get_text(GTK_ENTRY(widget)));
+  dt_metadata_set(imgid, "Xmp.dc.title", gtk_entry_get_text(GTK_ENTRY(widget)), FALSE, FALSE);
   dt_image_synch_xmp(imgid);
 
   return FALSE;
@@ -168,6 +168,8 @@ static void _lib_duplicate_thumb_press_callback(GtkWidget *widget, GdkEventButto
       int fw, fh;
       fw = fh = 0;
       dt_image_get_final_size(imgid, &fw, &fh);
+      if(d->cur_final_width <= 0)
+        dt_image_get_final_size(dev->image_storage.id, &d->cur_final_width, &d->cur_final_height);
       d->allow_zoom
           = (d->cur_final_width - fw < DUPLICATE_COMPARE_SIZE && d->cur_final_width - fw > -DUPLICATE_COMPARE_SIZE
              && d->cur_final_height - fh < DUPLICATE_COMPARE_SIZE
@@ -198,7 +200,7 @@ void gui_post_expose(dt_lib_module_t *self, cairo_t *cri, int32_t width, int32_t
 
   if (d->imgid == 0) return;
 
-  const int32_t tb = DT_PIXEL_APPLY_DPI(dt_conf_get_int("plugins/darkroom/ui/border_size"));
+  const int32_t tb = darktable.develop->border_size;
   int nw = width-2*tb;
   int nh = height-2*tb;
 
@@ -354,6 +356,9 @@ static gboolean _lib_duplicate_thumb_draw_callback (GtkWidget *widget, cairo_t *
 
 static void _lib_duplicate_init_callback(gpointer instance, dt_lib_module_t *self)
 {
+  //block signals to avoid concurrent calls
+  dt_control_signal_block_by_func(darktable.signals, G_CALLBACK(_lib_duplicate_init_callback), self);
+
   dt_lib_duplicate_t *d = (dt_lib_duplicate_t *)self->data;
 
   d->imgid = 0;
@@ -443,18 +448,25 @@ static void _lib_duplicate_init_callback(gpointer instance, dt_lib_module_t *sel
     gtk_widget_set_sensitive(bt, FALSE);
     gtk_widget_set_visible(bt, FALSE);
   }
-
-  // and we store the final size of the current image
+  // and reset the final size of the current image
   if(dev->image_storage.id >= 0)
-    dt_image_get_final_size(dev->image_storage.id, &d->cur_final_width, &d->cur_final_height);
+  {
+    d->cur_final_width = 0;
+    d->cur_final_height = 0;
+  }
+
+  dt_control_signal_unblock_by_func(darktable.signals, G_CALLBACK(_lib_duplicate_init_callback), self); //unblock signals
 }
 
 static void _lib_duplicate_mipmap_updated_callback(gpointer instance, dt_lib_module_t *self)
 {
   dt_lib_duplicate_t *d = (dt_lib_duplicate_t *)self->data;
-  // we store the final size of the current image
+  // we reset the final size of the current image
   if(darktable.develop->image_storage.id >= 0)
-    dt_image_get_final_size(darktable.develop->image_storage.id, &d->cur_final_width, &d->cur_final_height);
+  {
+    d->cur_final_width = 0;
+    d->cur_final_height = 0;
+  }
 
   gtk_widget_queue_draw (d->duplicate_box);
   dt_control_queue_redraw_center();
